@@ -4,6 +4,7 @@ type t =
 | Domain_young_ptr
 | Domain_young_start
 | Domain_young_end
+| Domain_young_trigger
 | Domain_current_stack
 | Domain_exn_handler
 | Domain_action_pending
@@ -17,9 +18,7 @@ type t =
 | Domain_sweeping_done
 | Domain_allocated_words
 | Domain_swept_words
-| Domain_major_work_computed
-| Domain_major_work_todo
-| Domain_major_gc_clock
+| Domain_major_slice_epoch
 | Domain_local_roots
 | Domain_ephe_info
 | Domain_final_info
@@ -30,6 +29,7 @@ type t =
 | Domain_compare_unordered
 | Domain_oo_next_id_local
 | Domain_requested_major_slice
+| Domain_requested_global_major_slice
 | Domain_requested_minor_gc
 | Domain_requested_external_interrupt
 | Domain_parser_trace
@@ -37,20 +37,19 @@ type t =
 | Domain_shared_heap
 | Domain_id
 | Domain_unique_id
-| Domain_pools_to_rescan
-| Domain_pools_to_rescan_len
-| Domain_pools_to_rescan_count
 | Domain_dls_root
 | Domain_extra_heap_resources
 | Domain_extra_heap_resources_minor
 | Domain_dependent_size
 | Domain_dependent_allocated
+| Domain_slice_target
+| Domain_slice_budget
+| Domain_major_work_done_between_slices
 | Domain_extern_state
 | Domain_intern_state
 | Domain_stat_minor_words
 | Domain_stat_promoted_words
 | Domain_stat_major_words
-| Domain_stat_minor_collections
 | Domain_stat_forced_major_collections
 | Domain_stat_blocks_marked
 | Domain_inside_stw_handler
