@@ -63,7 +63,7 @@ class virtual selector_generic : object
   (* The following methods must or can be overridden by the processor
      description *)
   method is_immediate : Mach.integer_operation -> int -> bool
-    (* Must be overriden to indicate whether a constant is a suitable
+    (* Must be overridden to indicate whether a constant is a suitable
        immediate operand to the given integer arithmetic instruction.
        The default implementation handles shifts by immediate amounts,
        but produces no immediate operations otherwise. *)
@@ -126,25 +126,31 @@ class virtual selector_generic : object
 
   method mark_c_tailcall : unit
   (* informs the code emitter that the current function may call
-     a C function that never returns; by default, does nothing.
+     a C function that never returns; by default, sets
+     [contains_calls := true] in [-g] mode and does nothing otherwise.
 
-     It is unnecessary to save the stack pointer in this situation
-     (which is the main purpose of tracking leaf functions) but some
-     architectures still need to ensure that the stack is properly
-     aligned when the C function is called. This is achieved by
-     overloading this method to set [contains_calls := true] *)
+     It is unnecessary to save the stack pointer in this situation,
+     unless we need to produce exact stack backtraces, hence the default
+     definition.
+
+     Some architectures still need to ensure that the stack is properly
+     aligned when the C function is called, regardless of [-g].
+     This is achieved by overloading this method to set
+     [contains_calls := true]. *)
 
   method mark_instr : Mach.instruction_desc -> unit
   (* dispatches on instructions to call one of the marking function
      above; overloading this is useful if Ispecific instructions need
      marking *)
 
-  (* The following method is the entry point and should not be overridden. *)
-  method emit_fundecl : Cmm.fundecl -> Mach.fundecl
+  (* The following method is the entry point and should not be overridden *)
+  method emit_fundecl : future_funcnames:Misc.Stdlib.String.Set.t
+                                              -> Cmm.fundecl -> Mach.fundecl
 
   (* The following methods should not be overridden.  They cannot be
      declared "private" in the current implementation because they
      are not always applied to "self", but ideally they should be private. *)
+  method extract_onto : Mach.instruction -> Mach.instruction
   method extract : Mach.instruction
   method insert :
     environment -> Mach.instruction_desc -> Reg.t array -> Reg.t array -> unit
